Struct WpImageDescriptionInfoV1

pub struct WpImageDescriptionInfoV1 { /* private fields */ }
Available on crate feature wayland and Linux only.
Colorimetric image description information

Sends all matching events describing an image description object exactly once and finally sends the ‘done’ event.

This means

  • if the image description is parametric, it must send
  • primaries
  • named_primaries, if applicable
  • at least one of tf_power and tf_named, as applicable
  • luminances
  • target_primaries
  • target_luminance
  • if the image description is parametric, it may send, if applicable,
  • target_max_cll
  • target_max_fall
  • if the image description contains an ICC profile, it must send the icc_file event

Once a wp_image_description_info_v1 object has delivered a ‘done’ event it is automatically destroyed.

Every wp_image_description_info_v1 created from the same wp_image_description_v1 shall always return the exact same data.

This interface has no requests.

Implementations



impl WpImageDescriptionInfoV1

pub fn done(&self)

end of information

Signals the end of information events and destroys the object.

pub fn icc_file(&self, icc: BorrowedFd<'_>, icc_size: u32)

ICC profile matching the image description

The icc argument provides a file descriptor to the client which may be memory-mapped to provide the ICC profile matching the image description. The fd is read-only, and if mapped then it must be mapped with MAP_PRIVATE by the client.

The ICC profile version and other details are determined by the compositor. There is no provision for a client to ask for a specific kind of a profile.

pub fn primaries( &self, r_x: i32, r_y: i32, g_x: i32, g_y: i32, b_x: i32, b_y: i32, w_x: i32, w_y: i32, )

primaries as chromaticity coordinates

Delivers the primary color volume primaries and white point using CIE 1931 xy chromaticity coordinates.

Each coordinate value is multiplied by 1 million to get the argument value to carry precision of 6 decimals.

pub fn primaries_named(&self, primaries: Primaries)

named primaries

Delivers the primary color volume primaries and white point using an explicitly enumerated named set.

pub fn tf_power(&self, eexp: u32)

transfer characteristic as a power curve

The color component transfer characteristic of this image description is a pure power curve. This event provides the exponent of the power function. This curve represents the conversion from electrical to optical pixel or color values.

The curve exponent has been multiplied by 10000 to get the argument eexp value to carry the precision of 4 decimals.

pub fn tf_named(&self, tf: TransferFunction)

named transfer characteristic

Delivers the transfer characteristic using an explicitly enumerated named function.

pub fn luminances(&self, min_lum: u32, max_lum: u32, reference_lum: u32)

primary color volume luminance range and reference white

Delivers the primary color volume luminance range and the reference white luminance level. These values include the minimum display emission and ambient flare luminances, assumed to be optically additive and have the chromaticity of the primary color volume white point.

The minimum luminance is multiplied by 10000 to get the argument ‘min_lum’ value and carries precision of 4 decimals. The maximum luminance and reference white luminance values are unscaled.

pub fn target_primaries( &self, r_x: i32, r_y: i32, g_x: i32, g_y: i32, b_x: i32, b_y: i32, w_x: i32, w_y: i32, )

target primaries as chromaticity coordinates

Provides the color primaries and white point of the target color volume using CIE 1931 xy chromaticity coordinates. This is compatible with the SMPTE ST 2086 definition of HDR static metadata for mastering displays.

While primary color volume is about how color is encoded, the target color volume is the actually displayable color volume. If target color volume is equal to the primary color volume, then this event is not sent.

Each coordinate value is multiplied by 1 million to get the argument value to carry precision of 6 decimals.

pub fn target_luminance(&self, min_lum: u32, max_lum: u32)

target luminance range

Provides the luminance range that the image description is targeting as the minimum and maximum absolute luminance L. These values include the minimum display emission and ambient flare luminances, assumed to be optically additive and have the chromaticity of the primary color volume white point. This should be compatible with the SMPTE ST 2086 definition of HDR static metadata.

This luminance range is only theoretical and may not correspond to the luminance of light emitted on an actual display.

Min L value is multiplied by 10000 to get the argument min_lum value and carry precision of 4 decimals. Max L value is unscaled for max_lum.

pub fn target_max_cll(&self, max_cll: u32)

target maximum content light level

Provides the targeted max_cll of the image description. max_cll is defined by CTA-861-H.

This luminance is only theoretical and may not correspond to the luminance of light emitted on an actual display.

pub fn target_max_fall(&self, max_fall: u32)

target maximum frame-average light level

Provides the targeted max_fall of the image description. max_fall is defined by CTA-861-H.

This luminance is only theoretical and may not correspond to the luminance of light emitted on an actual display.